Authentication
=============

.. automodule:: ironbeam.auth.api
   :members:
   :undoc-members:
   :show-inheritance:

Examples
--------

Here's a basic example of authentication:

.. literalinclude:: ../../../src/ironbeam/tests/test_auth.py
   :language: python
   :start-after: def test_auth_full_flow
   :end-before: # Add your test
   :dedent: 4

For more examples, see the :ref:`examples` section.